# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Ar(_AWS):
    _type = "ar"
    _icon_dir = "resources/aws/ar"


class ArVr(_Ar):
    _icon = "ar-vr.png"


class Sumerian(_Ar):
    _icon = "sumerian.png"


# Aliases
