# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Outscale


class _Storage(_Outscale):
    _type = "storage"
    _icon_dir = "resources/outscale/storage"


class SimpleStorageService(_Storage):
    _icon = "simple-storage-service.png"


class Storage(_Storage):
    _icon = "storage.png"


# Aliases
