# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Identity(_OnPrem):
    _type = "identity"
    _icon_dir = "resources/onprem/identity"


class Dex(_Identity):
    _icon = "dex.png"


# Aliases
