# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Firebase


class _Base(_Firebase):
    _type = "base"
    _icon_dir = "resources/firebase/base"


class Firebase(_Base):
    _icon = "firebase.png"


# Aliases
