# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Media(_Saas):
    _type = "media"
    _icon_dir = "resources/saas/media"


class Cloudinary(_Media):
    _icon = "cloudinary.png"


# Aliases
