# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AlibabaCloud


class _Web(_AlibabaCloud):
    _type = "web"
    _icon_dir = "resources/alibabacloud/web"


class Dns(_Web):
    _icon = "dns.png"


class Domain(_Web):
    _icon = "domain.png"


# Aliases
