# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Storage(_Generic):
    _type = "storage"
    _icon_dir = "resources/generic/storage"


class Storage(_Storage):
    _icon = "storage.png"


# Aliases
