# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Adjacentenablers(_OpenStack):
    _type = "adjacentenablers"
    _icon_dir = "resources/openstack/adjacentenablers"


# Aliases
