# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _GCP


class _Operations(_GCP):
    _type = "operations"
    _icon_dir = "resources/gcp/operations"


class Monitoring(_Operations):
    _icon = "monitoring.png"


# Aliases
