# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Chaos(_K8S):
    _type = "chaos"
    _icon_dir = "resources/k8s/chaos"


class ChaosMesh(_Chaos):
    _icon = "chaos-mesh.png"


class LitmusChaos(_Chaos):
    _icon = "litmus-chaos.png"


# Aliases
