# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AlibabaCloud


class _Iot(_AlibabaCloud):
    _type = "iot"
    _icon_dir = "resources/alibabacloud/iot"


class IotInternetDeviceId(_Iot):
    _icon = "iot-internet-device-id.png"


class IotLinkWan(_Iot):
    _icon = "iot-link-wan.png"


class IotMobileConnectionPackage(_Iot):
    _icon = "iot-mobile-connection-package.png"


class IotPlatform(_Iot):
    _icon = "iot-platform.png"


# Aliases
