# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Compute(_Generic):
    _type = "compute"
    _icon_dir = "resources/generic/compute"


class Rack(_Compute):
    _icon = "rack.png"


# Aliases
