# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Recommendation(_Saas):
    _type = "recommendation"
    _icon_dir = "resources/saas/recommendation"


class Recombee(_Recommendation):
    _icon = "recombee.png"


# Aliases
