# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Cdn(_Saas):
    _type = "cdn"
    _icon_dir = "resources/saas/cdn"


class Akamai(_Cdn):
    _icon = "akamai.png"


class Cloudflare(_Cdn):
    _icon = "cloudflare.png"


# Aliases
