# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Elastic


class _Security(_Elastic):
    _type = "security"
    _icon_dir = "resources/elastic/security"


class Endpoint(_Security):
    _icon = "endpoint.png"


class Security(_Security):
    _icon = "security.png"


class SIEM(_Security):
    _icon = "siem.png"


# Aliases
