# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Database(_Generic):
    _type = "database"
    _icon_dir = "resources/generic/database"


class SQL(_Database):
    _icon = "sql.png"


# Aliases
