# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Game(_AWS):
    _type = "game"
    _icon_dir = "resources/aws/game"


class GameTech(_Game):
    _icon = "game-tech.png"


class Gamelift(_Game):
    _icon = "gamelift.png"


# Aliases
