# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _NFV(_OpenStack):
    _type = "nfv"
    _icon_dir = "resources/openstack/nfv"


class Tacker(_NFV):
    _icon = "tacker.png"


# Aliases
