# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _GCP


class _API(_GCP):
    _type = "api"
    _icon_dir = "resources/gcp/api"


class APIGateway(_API):
    _icon = "api-gateway.png"


class Endpoints(_API):
    _icon = "endpoints.png"


# Aliases
