# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Elastic


class _Orchestration(_Elastic):
    _type = "orchestration"
    _icon_dir = "resources/elastic/orchestration"


class ECE(_Orchestration):
    _icon = "ece.png"


class ECK(_Orchestration):
    _icon = "eck.png"


# Aliases
