# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Firebase


class _Extentions(_Firebase):
    _type = "extentions"
    _icon_dir = "resources/firebase/extentions"


class Extensions(_Extentions):
    _icon = "extensions.png"


# Aliases
