# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Social(_Saas):
    _type = "social"
    _icon_dir = "resources/saas/social"


class Facebook(_Social):
    _icon = "facebook.png"


class Twitter(_Social):
    _icon = "twitter.png"


# Aliases
