# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Frontend(_OpenStack):
    _type = "frontend"
    _icon_dir = "resources/openstack/frontend"


class Horizon(_Frontend):
    _icon = "horizon.png"


# Aliases
