# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Outscale


class _Security(_Outscale):
    _type = "security"
    _icon_dir = "resources/outscale/security"


class Firewall(_Security):
    _icon = "firewall.png"


class IdentityAndAccessManagement(_Security):
    _icon = "identity-and-access-management.png"


# Aliases
