# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Firebase


class _Quality(_Firebase):
    _type = "quality"
    _icon_dir = "resources/firebase/quality"


class AppDistribution(_Quality):
    _icon = "app-distribution.png"


class CrashReporting(_Quality):
    _icon = "crash-reporting.png"


class Crashlytics(_Quality):
    _icon = "crashlytics.png"


class PerformanceMonitoring(_Quality):
    _icon = "performance-monitoring.png"


class TestLab(_Quality):
    _icon = "test-lab.png"


# Aliases
