# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Search(_OnPrem):
    _type = "search"
    _icon_dir = "resources/onprem/search"


class Solr(_Search):
    _icon = "solr.png"


# Aliases
