# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Elastic


class _Saas(_Elastic):
    _type = "saas"
    _icon_dir = "resources/elastic/saas"


class Cloud(_Saas):
    _icon = "cloud.png"


class Elastic(_Saas):
    _icon = "elastic.png"


# Aliases
