# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Others(_K8S):
    _type = "others"
    _icon_dir = "resources/k8s/others"


class CRD(_Others):
    _icon = "crd.png"


class PSP(_Others):
    _icon = "psp.png"


# Aliases
