# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Blank(_Generic):
    _type = "blank"
    _icon_dir = "resources/generic/blank"


class Blank(_Blank):
    _icon = "blank.png"


# Aliases
