# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Analytics(_Saas):
    _type = "analytics"
    _icon_dir = "resources/saas/analytics"


class Snowflake(_Analytics):
    _icon = "snowflake.png"


class Stitch(_Analytics):
    _icon = "stitch.png"


# Aliases
