# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AlibabaCloud


class _Communication(_AlibabaCloud):
    _type = "communication"
    _icon_dir = "resources/alibabacloud/communication"


class DirectMail(_Communication):
    _icon = "direct-mail.png"


class MobilePush(_Communication):
    _icon = "mobile-push.png"


# Aliases
