# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Filesharing(_Saas):
    _type = "filesharing"
    _icon_dir = "resources/saas/filesharing"


class Nextcloud(_Filesharing):
    _icon = "nextcloud.png"


# Aliases
