# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Packaging(_OpenStack):
    _type = "packaging"
    _icon_dir = "resources/openstack/packaging"


class LOCI(_Packaging):
    _icon = "loci.png"


class Puppet(_Packaging):
    _icon = "puppet.png"


class RPM(_Packaging):
    _icon = "rpm.png"


# Aliases
