# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _IBM


class _Storage(_IBM):
    _type = "storage"
    _icon_dir = "resources/ibm/storage"


class BlockStorage(_Storage):
    _icon = "block-storage.png"


class ObjectStorage(_Storage):
    _icon = "object-storage.png"


# Aliases
