# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Place(_Generic):
    _type = "place"
    _icon_dir = "resources/generic/place"


class Datacenter(_Place):
    _icon = "datacenter.png"


# Aliases
