# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Quantum(_AWS):
    _type = "quantum"
    _icon_dir = "resources/aws/quantum"


class Braket(_Quantum):
    _icon = "braket.png"


class QuantumTechnologies(_Quantum):
    _icon = "quantum-technologies.png"


# Aliases
