# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Programming


class _Runtime(_Programming):
    _type = "runtime"
    _icon_dir = "resources/programming/runtime"


class Dapr(_Runtime):
    _icon = "dapr.png"


# Aliases
