# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Etl(_OnPrem):
    _type = "etl"
    _icon_dir = "resources/onprem/etl"


class Embulk(_Etl):
    _icon = "embulk.png"


# Aliases
