# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Monitoring(_OpenStack):
    _type = "monitoring"
    _icon_dir = "resources/openstack/monitoring"


class Monasca(_Monitoring):
    _icon = "monasca.png"


class Telemetry(_Monitoring):
    _icon = "telemetry.png"


# Aliases
