# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Containerservices(_OpenStack):
    _type = "containerservices"
    _icon_dir = "resources/openstack/containerservices"


class Kuryr(_Containerservices):
    _icon = "kuryr.png"


# Aliases
