# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Proxmox(_OnPrem):
    _type = "proxmox"
    _icon_dir = "resources/onprem/proxmox"


class Pve(_Proxmox):
    _icon = "pve.png"


# Aliases

ProxmoxVE = Pve
