# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Apiproxies(_OpenStack):
    _type = "apiproxies"
    _icon_dir = "resources/openstack/apiproxies"


class EC2API(_Apiproxies):
    _icon = "ec2api.png"


# Aliases
