# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _User(_OpenStack):
    _type = "user"
    _icon_dir = "resources/openstack/user"


class Openstackclient(_User):
    _icon = "openstackclient.png"


# Aliases

OpenStackClient = Openstackclient
