# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Optimization(_OpenStack):
    _type = "optimization"
    _icon_dir = "resources/openstack/optimization"


class Congress(_Optimization):
    _icon = "congress.png"


class Rally(_Optimization):
    _icon = "rally.png"


class Vitrage(_Optimization):
    _icon = "vitrage.png"


class Watcher(_Optimization):
    _icon = "watcher.png"


# Aliases
