# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Multiregion(_OpenStack):
    _type = "multiregion"
    _icon_dir = "resources/openstack/multiregion"


class Tricircle(_Multiregion):
    _icon = "tricircle.png"


# Aliases
