# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _GCP


class _Migration(_GCP):
    _type = "migration"
    _icon_dir = "resources/gcp/migration"


class TransferAppliance(_Migration):
    _icon = "transfer-appliance.png"


# Aliases
