# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Operations(_OpenStack):
    _type = "operations"
    _icon_dir = "resources/openstack/operations"


# Aliases
