# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Cd(_OnPrem):
    _type = "cd"
    _icon_dir = "resources/onprem/cd"


class Spinnaker(_Cd):
    _icon = "spinnaker.png"


class TektonCli(_Cd):
    _icon = "tekton-cli.png"


class Tekton(_Cd):
    _icon = "tekton.png"


# Aliases
