# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Groupware(_OnPrem):
    _type = "groupware"
    _icon_dir = "resources/onprem/groupware"


class Nextcloud(_Groupware):
    _icon = "nextcloud.png"


# Aliases
