# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Networking(_OpenStack):
    _type = "networking"
    _icon_dir = "resources/openstack/networking"


class Designate(_Networking):
    _icon = "designate.png"


class Neutron(_Networking):
    _icon = "neutron.png"


class Octavia(_Networking):
    _icon = "octavia.png"


# Aliases
