# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Compute(_OpenStack):
    _type = "compute"
    _icon_dir = "resources/openstack/compute"


class Nova(_Compute):
    _icon = "nova.png"


class Qinling(_Compute):
    _icon = "qinling.png"


class Zun(_Compute):
    _icon = "zun.png"


# Aliases
