# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Generic


class _Device(_Generic):
    _type = "device"
    _icon_dir = "resources/generic/device"


class Mobile(_Device):
    _icon = "mobile.png"


class Tablet(_Device):
    _icon = "tablet.png"


# Aliases
