# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OpenStack


class _Billing(_OpenStack):
    _type = "billing"
    _icon_dir = "resources/openstack/billing"


class Cloudkitty(_Billing):
    _icon = "cloudkitty.png"


# Aliases

CloudKitty = Cloudkitty
