# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _AWS


class _Satellite(_AWS):
    _type = "satellite"
    _icon_dir = "resources/aws/satellite"


class GroundStation(_Satellite):
    _icon = "ground-station.png"


class Satellite(_Satellite):
    _icon = "satellite.png"


# Aliases
