# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Mlops(_OnPrem):
    _type = "mlops"
    _icon_dir = "resources/onprem/mlops"


class Polyaxon(_Mlops):
    _icon = "polyaxon.png"


# Aliases
