# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Programming


class _Framework(_Programming):
    _type = "framework"
    _icon_dir = "resources/programming/framework"


class Angular(_Framework):
    _icon = "angular.png"


class Backbone(_Framework):
    _icon = "backbone.png"


class Django(_Framework):
    _icon = "django.png"


class Ember(_Framework):
    _icon = "ember.png"


class Fastapi(_Framework):
    _icon = "fastapi.png"


class Flask(_Framework):
    _icon = "flask.png"


class Flutter(_Framework):
    _icon = "flutter.png"


class Laravel(_Framework):
    _icon = "laravel.png"


class Micronaut(_Framework):
    _icon = "micronaut.png"


class Rails(_Framework):
    _icon = "rails.png"


class React(_Framework):
    _icon = "react.png"


class Spring(_Framework):
    _icon = "spring.png"


class Starlette(_Framework):
    _icon = "starlette.png"


class Vue(_Framework):
    _icon = "vue.png"


# Aliases

FastAPI = Fastapi
