# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Saas


class _Identity(_Saas):
    _type = "identity"
    _icon_dir = "resources/saas/identity"


class Auth0(_Identity):
    _icon = "auth0.png"


class Okta(_Identity):
    _icon = "okta.png"


# Aliases
