# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _K8S


class _Group(_K8S):
    _type = "group"
    _icon_dir = "resources/k8s/group"


class NS(_Group):
    _icon = "ns.png"


# Aliases

Namespace = NS
