# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _OnPrem


class _Aggregator(_OnPrem):
    _type = "aggregator"
    _icon_dir = "resources/onprem/aggregator"


class Fluentd(_Aggregator):
    _icon = "fluentd.png"


class Vector(_Aggregator):
    _icon = "vector.png"


# Aliases
