# This module is automatically generated by autogen.sh. DO NOT EDIT.

from . import _Outscale


class _Compute(_Outscale):
    _type = "compute"
    _icon_dir = "resources/outscale/compute"


class Compute(_Compute):
    _icon = "compute.png"


class DirectConnect(_Compute):
    _icon = "direct-connect.png"


# Aliases
