"""
Firebase provides a set of services for Firebase provider.
"""

from diagrams import Node


class _Firebase(Node):
    _provider = "firebase"
    _icon_dir = "resources/firebase"

    fontcolor = "#ffffff"
